## cdist-type__postgres_database(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__postgres_database - create/drop postgres databases

## 2. DESCRIPTION

This cdist type allows you to create or drop postgres databases.

## 3. OPTIONAL PARAMETERS

state
  either present or absent
owner
  the role owning this database

## 4. EXAMPLES

    __postgres_database mydbname --owner mydbusername

## 5. SEE ALSO

- cdist-type(7)
- cdist-type__postgres_role(7)

## 6. COPYING

Copyright (C) 2011 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).